package com.takensoft.cms.author.service.Impl;

import com.takensoft.cms.author.dao.AuthorDAO;
import com.takensoft.cms.author.service.AuthorService;
import com.takensoft.cms.author.vo.AuthorVO;
import com.takensoft.cms.menu.service.MenuAuthorService;
import com.takensoft.common.Pagination;
import com.takensoft.common.util.JWTUtil;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * @author  : takensoft
 * @since   : 2024.04.01
 *
 * 권한 정보 관련 구현체
 * EgovAbstractServiceImpl : 전자정부 상속
 * AuthorService : 권한 정보 인터페이스 상속
 */
@Service("authorService")
@RequiredArgsConstructor
public class AuthorServiceImpl extends EgovAbstractServiceImpl implements AuthorService {
    private final AuthorDAO authorDAO;
    private final MenuAuthorService menuAuthorService;
    private final JWTUtil jwtUtil;

    /**
     * @author takensoft
     * @since 2024.04.05
     * 권한 중복 검사
     */
    @Override
    public boolean findByCheckAuthorCode(AuthorVO authorVO) throws Exception {
        return authorDAO.findByCheckAuthorCode(authorVO);
    }

    /**
     * @author takensoft
     * @since 2024.04.05
     * 권한 목록 조회
     */
    @Override
    public Map<String, Object> findAllAuthor(Map<String, String> params) throws Exception {
        Map<String, Object> result = new HashMap<String, Object>(); // 반환 객체 생성
        Pagination search = new Pagination(0, params); // 검색조건 객체 생성
        int cnt = authorDAO.findAllCnt(search); // 게시물 갯수
        Pagination pagination = new Pagination(cnt, params); // 게시물 갯수 조회 후 검색조건 객체 초기화
        List<AuthorVO> list = authorDAO.findAll(pagination); // 목록 조회

        result.put("list", list);
        result.put("pagination", pagination);

        return result;
    }

    /**
     * @author takensoft
     * @since 2024.04.05
     * 권한 상세 조회
     */
    @Override
    public AuthorVO findByAuthorCode(String authrtCd) throws Exception {
        AuthorVO result = new AuthorVO();
        if(authrtCd != null && !authrtCd.equals("")) {
            result = authorDAO.findByAuthorCode(authrtCd);
        } else {
            result.setUseYn("Y");
        }
        return result;
    }

    /**
     * @author takensoft
     * @since 2024.04.05
     * 권한 등록
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int authorSave(AuthorVO authorVO) throws Exception {
        // 등록된 토큰에서 사용자 정보 조회
        authorVO.setRgtr(jwtUtil.getWriter());
        int result = authorDAO.save(authorVO);
        
        // 메뉴별 권한 등록
        if(result > 0) {
            result += menuAuthorService.menuAuthrtSave(authorVO.getAuthrtCd(), "author");
        }
        return result;
    }

    /**
     * @author takensoft
     * @since 2024.04.05
     * 권한 수정
     */
    @Override
    public int authorUpdate(AuthorVO authorVO) throws Exception {
        // 등록된 토큰에서 사용자 정보 조회
        authorVO.setMdfr(jwtUtil.getWriter());
        return authorDAO.update(authorVO);
    }

    /**
     * @author takensoft
     * @since 2024.04.05
     * 전체 권한 목록 조회(신규 메뉴 등록 시 권한을 주기 위해 사용)
     */
    @Override
    public List<AuthorVO> findAllSystem() throws Exception {
        return authorDAO.findAllSystem();
    }
}
