package com.takensoft.cms.bbs.service;

import com.takensoft.cms.bbs.vo.BbsCnVO;
import com.takensoft.cms.popup.vo.PopupVO;
import com.takensoft.common.Pagination;
import org.springframework.web.multipart.MultipartFile;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author  : 하석형
 * @since   : 2024.05.09
 *
 * 게시판 관리 관련 인터페이스
 */
public interface BbsCnService {
    /**
     * @author  하석형
     * @since   2024.05.09
     * 게시판 아이디 중복 검사
     */
    public boolean bbsCnIdCheck(BbsCnVO bbsCnVO) throws Exception;

    /**
     * @author  하석형
     * @since   2024.05.09
     * 게시판 내용 등록
     */
    public HashMap<String, Object> saveBbsCn(BbsCnVO bbsCn, List<MultipartFile> multipartFileList, List<MultipartFile> multipartImgList) throws Exception;

    /**
     * @author  하석형
     * @since   2024.05.13
     * 게시판 내용 목록 조회 개수
     */
    public int findAllCnt(Pagination pagination) throws Exception;

    /**
     * @author  하석형
     * @since   2024.05.09
     * 게시판 내용 목록 조회
     */
    public Map<String, Object> findAllBbsCn(HashMap<String, String> params) throws Exception;

    /**
     * @author 하석형
     * @since  2024.05.09
     *
     * 게시판 관리 상세 조회
     */
    public BbsCnVO findByBbsId(String bbsId) throws Exception;

    /**
     * @author 하석형
     * @since  2024.05.09
     *
     * 게시판 관리 수정
     */
    public HashMap<String, Object> updateBbsCn(HashMap<String, Object> params, List<HashMap<String, Object>> deleteFileList, List<MultipartFile> multipartFileList, List<HashMap<String, Object>> deleteImgFileList, List<MultipartFile> multipartImgList) throws Exception;

    /**
     * @author 하석형
     * @since  2024.05.09
     *
     * 게시판 관리 삭제
     */
    public int deleteBbsCn(BbsCnVO bbsCnVO) throws Exception;

    /**
     * @author 방선주
     * @since  2024.05.22
     *
     * 조회수 증가
     */
    public int updateVwCnt(HashMap<String, Object> params) throws Exception;

    /**
     * @author 방선주
     * @since  2024.05.23
     *
     * 이전글 조회
     */
     public BbsCnVO findPrevBbsCn(BbsCnVO bbsCnVO) throws Exception;

    /**
     * @author 방선주
     * @since  2024.05.23
     *
     * 다음글 조회
     */
    public BbsCnVO findNextBbsCn(BbsCnVO bbsCnVO) throws Exception;
    /**
     * @author 방선주
     * @since  2024.05.30
     *
     * 첨부파일 이미지 경로 변경
     */
    public List<HashMap<String, Object>> fileListPathChange(String fileMngId) throws Exception;

    /**
     * @author 방선주
     * @since  2024.05.31
     *
     * 질의형 답변 등록
     */
    public HashMap<String, Object> saveAnswer(BbsCnVO bbsCnVO) throws Exception;

    /**
     * @author 방선주
     * @since  2024.05.31
     *
     * 질의형 답변 수정
     */
    public HashMap<String, Object> updateAnswer(BbsCnVO bbsCnVO) throws Exception;

    /**
     * @author 방선주
     * @since  2024.06.07
     *
     * 질의형 답변 삭제
     */
    public int deleteAns(BbsCnVO bbsCnVO) throws Exception;

    /**
     * @author 방선주
     * @since  2024.06.13
     *
     * 최신 공지 5개
     */
    public List<BbsCnVO> findFiveNotice(BbsCnVO bbsCn) throws Exception;
}