package com.takensoft.cms.bbs.service.Impl;

import com.takensoft.cms.bbs.dao.BbsTypeMngDAO;
import com.takensoft.cms.bbs.service.BbsTypeMngService;
import com.takensoft.cms.bbs.vo.BbsTypeMngVO;
import com.takensoft.common.idgen.service.IdgenService;
import com.takensoft.common.util.JWTUtil;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author  : 박정하
 * @since   : 2024.05.08
 *
 * 게시판 유형 관리 관련 구현체
 * EgovAbstractServiceImpl : 전자정부 상속
 * BbsTypeMngService : 게시판 유형 관리 인터페이스 상속
 */
@Service("bbsTypeMngService")
@RequiredArgsConstructor
public class BbsTypeMngServiceImpl extends EgovAbstractServiceImpl implements BbsTypeMngService {
    private final BbsTypeMngDAO bbsTypeMngDAO;
    private final IdgenService bbsTypeIdgn;
    private final JWTUtil jwtUtil;

    /**
     * @author  박정하
     * @since   2024.05.08
     * 게시판 유형 관리 등록
     */
    public HashMap<String, Object> insertBbsTypeMng(BbsTypeMngVO bbsTypeMngVO) throws Exception {
        HashMap<String, Object> result = new HashMap<>();

        // 게시판 유형 아이디 생성
        String bbsTypeMngId = bbsTypeIdgn.getNextStringId();
        bbsTypeMngVO.setBbsTypeId(bbsTypeMngId);

        // 등록된 토큰에서 사용자 정보 조회
        String writer = jwtUtil.getWriter();
        bbsTypeMngVO.setRgtr(writer);

        // 게시판 관리 등록
        int insertResult = bbsTypeMngDAO.insertBbsTypeMng(bbsTypeMngVO);

        result.put("bbsTypeMngId", bbsTypeMngId);
        result.put("result", insertResult);
        return result;
    }

    /**
     * @author  하석형
     * @since   2024.05.13
     * 게시판 유형 관리 목록 조회
     */
    public Map<String, Object> findAllBbsTypeMng(BbsTypeMngVO bbsTypeMngVO) throws Exception {
        Map<String, Object> result = new HashMap<>();

        List<BbsTypeMngVO> list = bbsTypeMngDAO.findAll(bbsTypeMngVO);
        result.put("list", list);
        return result;
    }

    /**
     * @author  하석형
     * @since   2024.05.13
     * 게시판 유형 관리 상세 조회
     */
    public BbsTypeMngVO findByBbsTypeId(String bbsTypeId) throws Exception {
        return bbsTypeMngDAO.findByBbsTypeId(bbsTypeId);
    }
}
