package com.takensoft.cms.bbs.web;

import com.takensoft.cms.bbs.service.WordMngService;
import com.takensoft.cms.bbs.vo.WordMngVO;
import com.takensoft.common.util.ResponseData;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.nio.charset.Charset;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author  : 방선주
 * @since   : 2024.05.31
 *
 * 금지 단어 관리 Controller
 */

@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value="/wordMng")
public class WordMngController {

    private final WordMngService wordMngService;

    /**
     * @author  방선주
     * @since   2024.05.09
     * @param   wordList
     * @return
     * @throws  Exception
     *
     * 금지어 추가
     */
    @PostMapping("/saveProc.json")
    public ResponseEntity<?> saveProc(@RequestBody HashMap<String, Object> wordList) throws Exception {
        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();

        // 금지어 등록
        int result = wordMngService.saveWords(wordList);

        if(result > 0) {
            responseData.setStatus(HttpStatus.OK);
            responseData.setMessage("정상적으로 등록 처리되었습니다.");
            responseData.setData(result);
            return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
        } else {
            responseData.setStatus(HttpStatus.INTERNAL_SERVER_ERROR);
            responseData.setMessage("등록에 실패하였습니다.\n담당자에게 문의하세요.");
            return new ResponseEntity<>(responseData, headers, HttpStatus.INTERNAL_SERVER_ERROR);
        }
    }
    @PostMapping("/findAll.json")
    public ResponseEntity<?> findAll(@RequestBody HashMap<String, String> params) throws Exception {
        // 금지어 목록 조회
        Map<String, Object> result = new HashMap<>();
        HashMap<String, Object> wordsList = wordMngService.findAllWord(params);


        result.put("words", wordsList);

        // 응답처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        responseData.setStatus(HttpStatus.OK);
        responseData.setMessage("정상적으로 조회가 처리되었습니다.");
        responseData.setData(result);
        return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
    }

    @PostMapping("/deleteProc.json")
    public ResponseEntity<?> deleteProc(@RequestBody HashMap<String, Object> params) throws Exception {
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();

        // 금지어 삭제
        int result = wordMngService.deleteWords(params);

        // 응답 처리
        if(result > 0) {
            responseData.setStatus(HttpStatus.OK);
            responseData.setMessage("정상적으로 삭제 처리되었습니다.");
            return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
        } else {
            responseData.setStatus(HttpStatus.INTERNAL_SERVER_ERROR);
            responseData.setMessage("삭제에 실패하였습니다.\n담당자에게 문의하세요.");
            return new ResponseEntity<>(responseData, headers, HttpStatus.INTERNAL_SERVER_ERROR);
        }
    }
}
