package com.takensoft.cms.codeManage.dao;

import com.takensoft.cms.codeManage.vo.CodeManageVO;
import com.takensoft.cms.dept.vo.DeptVO;
import com.takensoft.common.HierachyVO;
import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import java.util.List;

/**
 * @author  : takensoft
 * @since   : 2024.04.09
 *
 * 공통코드 정보 관련 Mapper
 */
@Mapper("codeManageDAO")
public interface CodeManageDAO {
    /**
     * @author takensoft
     * @since 2024.04.09
     * 공통 코드 중복 검사
     */
    boolean findByCheckCd(CodeManageVO codeManageVO);

    /**
     * @author takensoft
     * @since 2024.04.09
     * 코드 등록
     */
    int save(CodeManageVO codeManageVO);

    /**
     * @author takensoft
     * @since 2024.04.15
     * 코드 수정
     */
    int update(CodeManageVO codeManageVO);

    /**
     * @author takensoft
     * @since 2024.04.26
     * 상위코드가 수정됨에 따라 하위코드의 상위코드값 변경
     */
    int updateUpCd(CodeManageVO codeManageVO);

    /**
     * @author takensoft
     * @since 2024.04.09
     * 코드 깊이 조회
     */
    int findByCdGrd(String upCd);

    /**
     * @author takensoft
     * @since 2024.04.09
     * 코드 순서 조회
     */
    int findByCdSn(String upCd);

    /**
     * @author takensoft
     * @since 2024.04.09
     * 최상위 코드 조회
     */
    List<CodeManageVO> findTopCd();

    /**
     * @author takensoft
     * @since 2024.04.09
     * 하위 코드 조회[관리자용]
     */
    List<CodeManageVO> findChildCd(String cd);

    /**
     * @author takensoft
     * @since 2024.04.09
     * 하위 코드 조회[사용자용]
     */
    List<CodeManageVO> findChildCdUser(String cd);

    /**
     * @author takensoft
     * @since 2024.04.09
     * 코드 상세 조회
     */
    CodeManageVO findByCd(String cd);

    /**
     * @author takensoft
     * @since 2024.04.23
     * 코드 삭제
     */
    int deleteCd(String cd);

    /************************************** Hierachy 전용 **************************************/
    /**
     * @author takensoft
     * @since 2024.04.24
     * 최상위 코드 조회
     */
    List<HierachyVO> findByTopNode();
    /**
     * @author takensoft
     * @since 2024.04.24
     * 하위 코드 조회
     */
    List<HierachyVO> findChildNode(String id);
    /************************************** Hierachy 전용 **************************************/

    /**
     * @author 박정하
     * @since 2024.05.10
     * 공통 코드 목록 정보 수정 (hierachyVO 사용)
     */
    public int codeUpdateByHierachy(CodeManageVO codeManageVO) throws Exception;
}