package com.takensoft.cms.main.service.Impl;

import com.takensoft.cms.bbs.dao.BbsCnDAO;
import com.takensoft.cms.main.dao.MainDAO;
import com.takensoft.cms.main.service.MainService;
import com.takensoft.cms.popup.dao.PopupDAO;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author  : 박정하
 * @since   : 2024.05.29
 *
 * 메인 관련 인터페이스
 * EgovAbstractServiceImpl : 전자정부 상속
 * GovernmentMainService : 메인 관련 인터페이스 상속
 */
@Service("mainService")
@RequiredArgsConstructor
public class MainServiceImpl extends EgovAbstractServiceImpl implements MainService {
    private final MainDAO mainDAO;
    private final PopupDAO popupDAO;
    private final BbsCnDAO bbsCnDAO;

    /**
     * @author takensoft
     * @since 2024.05.27
     *
     * 관리자 메인페이지 통계정보 조회 [ 신규회원 가입자 수, 오늘 방문자 수, 이번달 방문자 수, 총 방문자 수 ]
     */
    @Override
    public Map<String, Object> selectAdminMain() throws Exception {
        Map<String, Object> result = new HashMap<>();

        // 팝업 관리
        result.put("popupMng", popupDAO.selectPopupListByNew());
        
        // 최신 등록 글
        result.put("bbsCnNew", bbsCnDAO.selectBbsCnListByNew());

        // 신규회원 가입자 수
        // result.put("cntnNewCnt", mainDAO.selectCntnNewCnt());

        // 오늘 방문자 수
        result.put("cntnDayCnt", mainDAO.selectCntnDayCnt());

        // 이번달 방문자 수
        result.put("cntnMmCnt", mainDAO.selectCntnMmCnt());

        // 총 방문자 수
        result.put("cntnTotalCnt", mainDAO.selectCntnTotalCnt());

        // 방문자 접속 통계
        result.put("monthCntnStats", mainDAO.findByMonthCntnStats());

        return result;
    }

    /**
     * @author 박정하
     * @since 2024.06.14
     *
     * 관리자 메인페이지 기업상담신청 알람
     */
    public List<HashMap<String, Object>> findAplyToasts() throws Exception {
        return mainDAO.findAplyToasts();
    }
}