package com.takensoft.cms.mber.service.Impl;


import com.takensoft.cms.codeManage.service.CodeManageService;
import com.takensoft.cms.codeManage.vo.CodeManageVO;
import com.takensoft.cms.mber.dao.LgnHstryDAO;
import com.takensoft.cms.mber.service.LgnHstryService;
import com.takensoft.cms.mber.vo.LgnHstryVO;
import com.takensoft.cms.popup.vo.PopupVO;
import com.takensoft.common.Pagination;
import com.takensoft.common.util.JWTUtil;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;

/**
 * @author  : takensoft
 * @since   : 2024.04.09
 *
 * 로그인 이력 정보 관련 구현체
 * EgovAbstractServiceImpl : 전자정부 상속
 * LgnHstryService : 로그인 이력 정보 인터페이스 상속
 */
@Service("lgnHstryService")
@RequiredArgsConstructor
public class LgnHstryServiceImpl extends EgovAbstractServiceImpl implements LgnHstryService {
    private final LgnHstryDAO lgnHstryDAO;
    private final CodeManageService codeManageService;

    /**
     * @author takensoft
     * @since 2024.04.09
     * 로그인 이력 등록
     */
    @Override
    public int LgnHstrySave(LgnHstryVO lgnHstryVO) throws Exception {
        return lgnHstryDAO.save(lgnHstryVO);
    }

    /**
     * @author  : 박정하
     * @since   : 2024.05.13
     *
     * 로그인 이력 목록 조회
     */
    @Override
    public HashMap<String, Object> lgnHstryList(HashMap<String, String> params) throws Exception {
        Pagination search = new Pagination(0, params);
        int cnt = lgnHstryDAO.selectLgnHstryListCnt(search);

        Pagination pagination = new Pagination(cnt, params);
        List<LgnHstryVO> list = lgnHstryDAO.selectLgnHstryList(pagination);
        List<CodeManageVO> codeList = codeManageService.findByChildCdCache("lgnHstry"); // 검색 조건

        HashMap<String, Object> result = new HashMap<>();
        result.put("list", list);
        result.put("pagination", pagination);
        result.put("codeList", codeList);
        return result;
    }
}