package com.takensoft.cms.menu.dao;

import com.takensoft.cms.author.vo.AuthorVO;
import com.takensoft.cms.contsType.vo.ContsTypeVO;
import com.takensoft.cms.dept.vo.DeptVO;
import com.takensoft.cms.menu.vo.*;
import com.takensoft.common.HierachyVO;
import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import java.util.HashMap;
import java.util.List;

/**
 * @author  : takensoft
 * @since   : 2024.04.01
 *
 * 메뉴 정보 관련 Mapper
 */
@Mapper("menuDAO")
public interface MenuDAO {
    /**
     * @author takensoft
     * @since 2024.04.08
     * 최상위 메뉴 조회
     */
    List<MenuVO> findTopMenu();

    /**
     * @author takensoft
     * @since 2024.04.08
     * 하위 메뉴 조회
     */
    List<MenuVO> findChildMenus(String menuId);

    /**
     * @author takensoft
     * @since 2024.04.15
     * 메뉴 전체 조회(최상위 메뉴 제외-> grd:0)
     */
    List<MenuVO> findExceptTopMenu();

    /**
     * @author takensoft
     * @since 2024.04.08
     * 메뉴 등록
     */
    int save(MenuVO menuVO);

    /**
     * @author takensoft
     * @since 2024.04.15
     * 메뉴 수정
     */
    int update(MenuVO menuVO);

    /**
     * @author takensoft
     * @since 2024.04.08
     * 메뉴 상세 조회
     */
    MenuVO findByMenu(String menuId);

    /**
     * @author takensoft
     * @since 2024.04.08
     * 메뉴 깊이 조회
     */
    int findByMenuGrd(String upMenuId);

    /**
     * @author takensoft
     * @since 2024.04.08
     * 메뉴 순서 조회
     */
    int findByMenuSn(String upMenuId);

    /**
     * @author takensoft
     * @since 2024.04.08
     * 메뉴별 만족도 등록
     */
    int saveMenuStsfdg(MenuStsfdgVO menuStsfdgVO);

    /************************************** Hierachy 전용 **************************************/
    /**
     * @author takensoft
     * @since 2024.04.25
     * 최상위 부서 조회
     */
    List<HierachyVO> findByTopNode();
    /**
     * @author takensoft
     * @since 2024.04.24
     * 하위 부서 조회
     */
    List<HierachyVO> findChildNode(String id);
    /************************************** Hierachy 전용 **************************************/

    /**
     * @author 박정하
     * @since 2024.04.29
     * 상위,하위 메뉴 삭제
     */
    int deleteMenu(MenuVO menuVO);

    /**
     * @author 박정하
     * @since 2024.05.02
     * 상위 메뉴 조회
     */
    String findUpMenuId(String MenuId);

    /**
     * @author takensoft
     * @since 2024.05.09
     * 메뉴 조회(시스템용)
     */
    List<SysMenuVO> findByMenuWithRouter(MenuRequest menuRequest);

    /**
     * @author 박정하
     * @since 2024.05.10
     * 메뉴 정보 수정 (hierachyVO 사용)
     */
    public int menuUpdateByHierachy(MenuVO menuVO) throws Exception;

    /**
     * @author 박정하
     * @since 2024.05.10
     * 메뉴 수정 (콘텐츠 유형)
     */
    public int updateByContsId(ContsTypeVO contsTypeVO) throws Exception;

    /**
     * @author 방선주
     * @since 2024.06.07
     * 게시판 관리에서 게시판 삭제 시 게시판 메뉴 미노출로 변경
     */
    public int bbsMngMenuDelete(MenuVO menuVO) throws Exception;

    /**
     * @author 박정하
     * @since 2024.07.18
     * 메뉴 개수 조회 (접속 통계용)
     */
    public int findAllCnt(HashMap<String, Object> params) throws Exception;
}
