package com.takensoft.cms.prvcInqHstry.service.Impl;

import com.takensoft.cms.codeManage.service.CodeManageService;
import com.takensoft.cms.codeManage.vo.CodeManageVO;
import com.takensoft.cms.popup.vo.PopupVO;
import com.takensoft.cms.prvcInqHstry.dao.PrvcInqHstryDAO;
import com.takensoft.cms.prvcInqHstry.service.PrvcInqHstryService;
import com.takensoft.cms.prvcInqHstry.vo.PrvcInqHstryVO;
import com.takensoft.common.Pagination;
import com.takensoft.common.util.CommonUtils;
import com.takensoft.common.util.JWTUtil;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;

/**
 * @author  : 박정하
 * @since   : 2024.05.22
 *
 * 개인정보 조회 이력 관련 구현체
 * EgovAbstractServiceImpl : 전자정부 상속
 * PrvcInqHstryService : 팝업 관련 인터페이스 상속
 */
@Service("prvcInqHstryService")
@RequiredArgsConstructor
public class PrvcInqHstryServiceImpl extends EgovAbstractServiceImpl implements PrvcInqHstryService {
    private final JWTUtil jwtUtil;
    private final CommonUtils commonUtils;
    private final PrvcInqHstryDAO prvcInqHstryDAO;
    private final CodeManageService codeManageService;

    /**
     * @author  : 박정하
     * @since   : 2024.05.22
     *
     * 개인정보 조회 이력 등록
     */
    public int prvcInqHstryInsert(HttpServletRequest request, PrvcInqHstryVO prvcInqHstryVO) throws Exception {
        // 조회 아이피 삽입
        String ipAdd = commonUtils.getIp(request);
        prvcInqHstryVO.setInqIp(ipAdd);

        // 조회자 삽입
        String writer = jwtUtil.getWriter();
        prvcInqHstryVO.setRdr(writer);

        return prvcInqHstryDAO.insertPrvcInqHstry(prvcInqHstryVO);
    }

    /**
     * @author  : 박정하
     * @since   : 2024.05.27
     *
     * 개인정보 조회 이력 목록 조회
     */
    @Override
    public HashMap<String, Object> prvcInqHstryList(HashMap<String, String> params) throws Exception {
        Pagination search = new Pagination(0, params);
        int cnt = prvcInqHstryDAO.selectPrvcInqHstryListCnt(search);

        Pagination pagination = new Pagination(cnt, params);
        List<PrvcInqHstryVO> list = prvcInqHstryDAO.selectPrvcInqHstryList(pagination);
        List<CodeManageVO> codeList = codeManageService.findByChildCdCache("prvcInqHstry"); // 검색 조건

        HashMap<String, Object> result = new HashMap<>();
        result.put("list", list);
        result.put("pagination", pagination);
        result.put("codeList", codeList);
        return result;
    }

    /**
     * @author  : 박정하
     * @since   : 2024.05.27
     *
     * 개인정보 조회 이력 상세 조회
     */
    @Override
    public PrvcInqHstryVO prvcInqHstryDetail(int inqHstryId) throws Exception {
        return prvcInqHstryDAO.selectPrvcInqHstryDetail(inqHstryId);
    }
}