package com.takensoft.cms.prvcInqHstry.web;

import com.takensoft.cms.prvcInqHstry.service.PrvcInqHstryService;
import com.takensoft.cms.prvcInqHstry.vo.PrvcInqHstryVO;
import com.takensoft.common.util.ResponseData;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.nio.charset.Charset;
import java.util.*;

/**
 * @author  : 박정하
 * @since   : 2024.05.22
 *
 * 개인정보 조회 이력 관련 컨트롤러
 */
@RestController
@RequiredArgsConstructor
@RequestMapping(value = "/admin/prvcInqHstry")
public class PrvcInqHstryController {
    private final PrvcInqHstryService prvcInqHstryService;

    /**
     * @author 박정하
     * @since 2024.05.22
     * @param prvcInqHstryVO
     * @return
     * @throws Exception
     *
     * 개인정보 조회 이력 등록
     */
    @PostMapping("/insertProc.json")
    public ResponseEntity<?> insertProc(HttpServletRequest request, @RequestBody PrvcInqHstryVO prvcInqHstryVO) throws Exception {
        int result = prvcInqHstryService.prvcInqHstryInsert(request, prvcInqHstryVO);

        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        if(result > 0) {
            responseData.setStatus(HttpStatus.OK);
            responseData.setMessage("정상적으로 등록 처리되었습니다.");
            return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
        } else {
            responseData.setStatus(HttpStatus.INTERNAL_SERVER_ERROR);
            responseData.setMessage("등록에 실패하였습니다.\n담당자에게 문의하세요.");
            return new ResponseEntity<>(responseData, headers, HttpStatus.INTERNAL_SERVER_ERROR);
        }
    }

    /**
     * @author 박정하
     * @since 2024.05.27
     * @param params
     * @return
     * @throws Exception
     *
     * 개인정보 조회 이력 목록 조회
     */
    @PostMapping("/listProc.json")
    public ResponseEntity<?> listProc(@RequestBody HashMap<String, String> params) throws Exception {
        HashMap<String, Object> result = prvcInqHstryService.prvcInqHstryList(params);

        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        responseData.setStatus(HttpStatus.OK);
        responseData.setMessage("정상적으로 조회가 처리되었습니다.");
        responseData.setData(result);
        return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
    }

    /**
     * @author 박정하
     * @since 2024.05.27
     * @param prvcInqHstryVO
     * @return
     * @throws Exception
     *
     * 개인정보 조회 이력 상세 조회
     */
    @PostMapping("/detailProc.json")
    public ResponseEntity<?> listProc(@RequestBody PrvcInqHstryVO prvcInqHstryVO) throws Exception {
        PrvcInqHstryVO result = prvcInqHstryService.prvcInqHstryDetail(prvcInqHstryVO.getInqHstryId());

        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        responseData.setStatus(HttpStatus.OK);
        responseData.setMessage("정상적으로 조회가 처리되었습니다.");
        responseData.setData(result);
        return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
    }
}