package com.takensoft.portal.entDscsnAply.web;

import com.takensoft.common.file.service.FileService;
import com.takensoft.common.util.ResponseData;
import com.takensoft.portal.entDscsnAply.service.EntDscsnAplyService;
import com.takensoft.portal.entDscsnAply.vo.EntDscsnAplyVO;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.nio.charset.Charset;
import java.util.*;

/**
 * @author  : 박정하
 * @since   : 2024.04.02
 *
 * 기업상담신청 관련 컨트롤러
 */
@RestController
@RequiredArgsConstructor
public class EntDscsnAplyController {
    private final EntDscsnAplyService entDscsnAplyService;
    private final FileService fileService;

    /**
     * @author 박정하
     * @since 2024.04.02
     * @param entDscsnAplyVO
     * @return
     * @throws Exception
     *
     * 기업상담신청 등록
     */
    @PostMapping(path = "/sys/entDscsnAply/insertProc.file")
    public ResponseEntity<?> insertProc(HttpServletRequest request, EntDscsnAplyVO entDscsnAplyVO) throws Exception {
        HashMap<String, Object> result = entDscsnAplyService.entDscsnAplyInsert(request, entDscsnAplyVO);
        int insertResult = (int)result.get("insertResult");

        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        if (insertResult > 0) {
            responseData.setStatus(HttpStatus.OK);
            responseData.setMessage("정상적으로 문의 등록되었습니다.");
            return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
        } else if(insertResult < 0) {
            responseData.setStatus(HttpStatus.PAYLOAD_TOO_LARGE);
            responseData.setMessage("업로드 가능한 파일 용량 제한을 초과했습니다.");
            return new ResponseEntity<>(responseData, headers, HttpStatus.PAYLOAD_TOO_LARGE);
        } else {
            if (result.containsKey("writeCount") && result.containsKey("lastDatetime")) {
                responseData.setStatus(HttpStatus.TOO_MANY_REQUESTS);
                responseData.setMessage("주어진 시간 동안 너무 많은 문의를 등록했습니다. " + result.get("lastDatetime") + " 후에 재시도하세요.");
                return new ResponseEntity<>(responseData, headers, HttpStatus.TOO_MANY_REQUESTS);
            } else {
                responseData.setStatus(HttpStatus.INTERNAL_SERVER_ERROR);
                responseData.setMessage("문의 등록에 실패하였습니다.\n담당자에게 문의하세요.");
                return new ResponseEntity<>(responseData, headers, HttpStatus.INTERNAL_SERVER_ERROR);
            }
        }
    }

    /**
     * @author 박정하
     * @since 2024.04.02
     * @param params
     * @return
     * @throws Exception
     *
     * 기업상담신청 목록 조회
     */
    @PostMapping(path = "/government/entDscsnAply/listProc.json")
    public ResponseEntity<?> listProc(HttpServletRequest request, @RequestBody Map<String, String> params) throws Exception {
        Map<String, Object> result = entDscsnAplyService.entDscsnAplyList(request, params);

        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        responseData.setStatus(HttpStatus.OK);
        responseData.setMessage("정상적으로 기업상담신청 목록 조회가 처리되었습니다.");
        responseData.setData(result);
        return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
    }

    /**
     * @author 박정하
     * @since 2024.04.02
     * @param entDscsnAplyVO
     * @return
     * @throws Exception
     *
     * 기업상담신청 상세 조회
     */
    @PostMapping(path = "/sys/entDscsnAply/detailProc.json")
    public ResponseEntity<?> detailProc(@RequestBody EntDscsnAplyVO entDscsnAplyVO) throws Exception {
        EntDscsnAplyVO result = entDscsnAplyService.entDscsnAplyDetail(entDscsnAplyVO);

        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        responseData.setStatus(HttpStatus.OK);
        responseData.setMessage("정상적으로 기업상담신청 상세 조회가 처리되었습니다.");
        responseData.setData(result);
        return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
    }

    /**
     * @author 박정하
     * @since 2024.04.02
     * @param entDscsnAplyVO
     * @return
     * @throws Exception
     *
     * 기업상담신청 수정
     */
    @PostMapping(path = "/sys/entDscsnAply/update.json")
    public ResponseEntity<?> entDscsnAplyUpdate(@RequestBody EntDscsnAplyVO entDscsnAplyVO) throws Exception {
        int result = entDscsnAplyService.entDscsnAplyUpdate(entDscsnAplyVO);

        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        if (result > 0) {
            responseData.setStatus(HttpStatus.OK);
            responseData.setMessage("정상적으로 처리되었습니다.");
            return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
        } else if(result < 0) {
            responseData.setStatus(HttpStatus.PAYLOAD_TOO_LARGE);
            responseData.setMessage("업로드 가능한 파일 용량 제한을 초과했습니다.");
            return new ResponseEntity<>(responseData, headers, HttpStatus.PAYLOAD_TOO_LARGE);
        } else {
            responseData.setStatus(HttpStatus.BAD_REQUEST);
            responseData.setMessage("요청 적용에 실패하였습니다.\n담당자에게 문의하세요.");
            return new ResponseEntity<>(responseData, headers, HttpStatus.BAD_REQUEST);
        }
    }
}