package com.takensoft.portal.main.service.impl;

import com.takensoft.cms.codeManage.service.CodeManageService;
import com.takensoft.cms.codeManage.vo.CodeManageVO;
import com.takensoft.portal.entInfo.dao.EntInfoDAO;
import com.takensoft.portal.main.dao.GovernmentMainDAO;
import com.takensoft.portal.main.service.GovernmentMainService;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author  : 박정하
 * @since   : 2024.05.29
 *
 * 메인 관련 인터페이스
 * EgovAbstractServiceImpl : 전자정부 상속
 * GovernmentMainService : 메인 관련 인터페이스 상속
 */
@Service("governmentMainService")
@RequiredArgsConstructor
public class GovernmentMainServiceImpl extends EgovAbstractServiceImpl implements GovernmentMainService {
    private final GovernmentMainDAO governmentMainDAO;
    private final EntInfoDAO entInfoDAO;
    private final CodeManageService codeManageService;

    /**
     * @author 박정하
     * @since 2024.05.29
     *
     * 공무원 메인페이지 통계정보 조회 [ 분류별 통계, 상담신청 통계, 검토사항 통계, 공지사항 최신글, 기업정보 최신글 ]
     */
    @Override
    public Map<String, Object> selectGovernmentMain(HashMap<String, String> params) throws Exception {
        Map<String, Object> result = new HashMap<>();

        // 검색조건
        result.put("codeList", codeManageService.findByChildCdCache("governmentMainTab"));

        String tab = params.get("activeTab");
        if (tab != null) {
            // 분류별 통계
            if (tab.equals("categoryTab")) {
                result.put("governmentStats", governmentMainDAO.selectCategoryStats(params));
            }

            // 상담신청 통계
            else if (tab.equals("entDscsnAplyTab")) {
                result.put("governmentStats", governmentMainDAO.selectEntDscsnAplyStats(params));
            }

            // 검토사항 통계
            else if (tab.equals("rvwMttrTab")) {
                result.put("governmentStats", governmentMainDAO.selectRvwMttrStats(params));
            }
        }

        // 기업정보 최신글
        result.put("companyInfo", entInfoDAO.selectCompanyInfoListByNew());

        return result;
    }
}