package com.takensoft.portal.statistics.web;

import com.takensoft.common.util.ResponseData;
import com.takensoft.portal.statistics.service.StatisticsService;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.nio.charset.Charset;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author  : 박정하
 * @since   : 2024.06.13
 *
 * 통계 관련 컨트롤러
 */
@RestController
@RequiredArgsConstructor
@RequestMapping(value = "/government/statistics")
public class StatisticsController {
    private final StatisticsService statisticsService;

    /**
     * @author 박정하
     * @since 2024.06.13
     * @param params
     * @return
     * @throws Exception
     *
     * 분류별 통계 조회
     */
    @PostMapping("/categoryStatistics.json")
    public ResponseEntity<?> categoryStatistics(@RequestBody HashMap<String, String> params) throws Exception {
        List<HashMap<String, Object>> result = statisticsService.categoryStatistics(params);

        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        responseData.setStatus(HttpStatus.OK);
        responseData.setMessage("정상적으로 조회가 처리되었습니다.");
        responseData.setData(result);
        return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
    }

    /**
     * @author 박정하
     * @since 2024.06.13
     * @param params
     * @return
     * @throws Exception
     *
     * 검토사항 통계 조회
     */
    @PostMapping("/rvwMttrStatistics.json")
    public ResponseEntity<?> rvwMttrStatistics(@RequestBody HashMap<String, String> params) throws Exception {
        Map<String, Object> result = statisticsService.rvwMttrStatistics(params);

        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        responseData.setStatus(HttpStatus.OK);
        responseData.setMessage("정상적으로 조회가 처리되었습니다.");
        responseData.setData(result);
        return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
    }

    /**
     * @author 박정하
     * @since 2024.06.14
     * @param params
     * @return
     * @throws Exception
     *
     * 상담신청 통계 조회
     */
    @PostMapping("/consultationStatistics.json")
    public ResponseEntity<?> consultationStatistics(@RequestBody HashMap<String, String> params) throws Exception {
        List<HashMap<String, Object>> result = statisticsService.consultationStatistics(params);

        // 응답 처리
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(new MediaType("application", "json", Charset.forName("UTF-8")));
        ResponseData responseData = new ResponseData();
        responseData.setStatus(HttpStatus.OK);
        responseData.setMessage("정상적으로 조회가 처리되었습니다.");
        responseData.setData(result);
        return new ResponseEntity<>(responseData, headers, HttpStatus.OK);
    }
}